@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.27.2.3 2005/04/09 21:12:54 chpe Exp $
+ *  $Id: mozilla-helpers.cpp,v 1.27.2.4 2005/04/26 12:04:08 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -363,7 +363,7 @@ PageInfoHelper::GetCacheEntryDescriptor (const nsAString &aUrl,
   
       nsCOMPtr<nsICacheEntryDescriptor> cacheEntryDescriptor;
   
-#ifdef MOZ_NSICACHESESSION_OPENCACHEENTRY_NSACSTRING_
+#ifdef HAVE_GECKO_1_8
       rv = cacheSession->OpenCacheEntry (nsEmbedCString(url), nsICache::ACCESS_READ,
                                          PR_FALSE, aEntry);
 #else
