@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sidebar-extension.c,v 1.9 2005/03/07 19:11:08 jordim Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -229,6 +229,10 @@ sidebar_page_changed_cb (GtkWidget* sidebar,
 	ephy_sidebar_embed_set_url (EPHY_SIDEBAR_EMBED (data->embed), page_id);
 	ephy_sidebar_set_content (EPHY_SIDEBAR (data->sidebar),
 				  GTK_WIDGET (data->embed));
+
+	/* This is a workaround for bug: #169116 */
+	gtk_widget_hide(GTK_WIDGET (data->embed));
+
 	gtk_widget_show (GTK_WIDGET (data->embed));
 
 	/* Remeber the current page */
